From d24412afcfccccd68c22b930bec1707943913462 Mon Sep 17 00:00:00 2001
From: F. Yhuel <fyhuel@viotech.net>
Date: Fri, 29 Jul 2011 17:18:29 +0200
Subject: [PATCH] HLS (httplive.c): clean-up of Peek() function

The Peek() function used to peek the next segment if the current one
didn't have the required size (if i_peek > segment->data->i_buffer).
It doesn't seem necessary and increase quite a lot the complexity of
the function.

This new Peek() simply returns the available data size, i.e. i_buffer.
---
 modules/stream_filter/httplive.c |   26 ++++----------------------
 1 files changed, 4 insertions(+), 22 deletions(-)

diff --git a/modules/stream_filter/httplive.c b/modules/stream_filter/httplive.c
index cc3fe48..1407b72 100644
--- a/modules/stream_filter/httplive.c
+++ b/modules/stream_filter/httplive.c
@@ -1850,10 +1850,9 @@ static int Read(stream_t *s, void *buffer, unsigned int i_read)
 static int Peek(stream_t *s, const uint8_t **pp_peek, unsigned int i_peek)
 {
     stream_sys_t *p_sys = s->p_sys;
-    size_t curlen = 0;
+    size_t available = 0;
     segment_t *segment;
 
-again:
     segment = GetSegment(s);
     if (segment == NULL)
     {
@@ -1864,29 +1863,12 @@ again:
 
     vlc_mutex_lock(&segment->lock);
 
-    /* remember segment to peek */
-    int peek_segment = p_sys->playback.segment;
-    do
-    {
-        if (i_peek < segment->data->i_buffer)
-        {
-            *pp_peek = segment->data->p_buffer;
-            curlen += i_peek;
-        }
-        else
-        {
-            p_sys->playback.segment++;
-            vlc_mutex_unlock(&segment->lock);
-            goto again;
-        }
-    } while ((curlen < i_peek) && vlc_object_alive(s));
-
-    /* restore segment to read */
-    p_sys->playback.segment = peek_segment;
+    *pp_peek = segment->data->p_buffer;
+    available = segment->data->i_buffer;
 
     vlc_mutex_unlock(&segment->lock);
 
-    return curlen;
+    return available;
 }
 
 static bool hls_MaySeek(stream_t *s)
-- 
1.7.4.1

